<template>
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" label-width="auto">
        <el-row :gutter="10">
          <el-col :span="7">
            <el-form-item label="告警时间">
              <el-date-picker v-model="querys[0].value" end-placeholder="结束日期" range-separator="至"
                              start-placeholder="开始日期" style="width: 100%" type="datetimerange"
                              value-format="yyyy-MM-dd HH:mm:ss">
              </el-date-picker>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="设备名称">
              <el-input v-model="querys[1].value" clearable maxlength="32" placeholder="请输入设备名称">
              </el-input>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item label="处理状态">
              <el-select v-model="querys[2].value" clearable placeholder="请选择处理状态" style="width: 100%">
                <el-option v-for="item in handleStatusList" :key="item.value" :label="item.name" :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="4">
            <el-button icon="el-icon-search" type="primary" @click="handleSearch">搜索
            </el-button>
            <el-button icon="el-icon-refresh" @click="handleReset">重置
            </el-button>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div ref="contentPanel" class="bbsl-table-content">
      <div ref="btnPanel" class="bbsl-btn-content"></div>
      <el-table ref="multipleSelection" v-loading="loading" :cell-style="{ 'text-align': 'center' }" :data="tableData" :header-cell-style="{ 'text-align': 'center' }"
                :max-height="tableMaxHeight" :style="{ width: '100%' }" border
                size="mini" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
        <el-table-column fixed label="序号" type="index" width="55"></el-table-column>
        <!--        <el-table-column min-width="100" fixed prop="deviceCode" label="告警设备标识" show-overflow-tooltip>-->
        <!--        </el-table-column>-->
        <el-table-column fixed label="设备名称" min-width="100" prop="deviceName" show-overflow-tooltip>
        </el-table-column>
        <el-table-column fixed label="告警名称" min-width="160" prop="warnName" show-overflow-tooltip>
          <template slot-scope="scope">
            <span class="active" @click="toDialog(scope.row.deviceName)">{{
                scope.row.deviceName
              }}</span>
          </template>
        </el-table-column>
        <!-- <el-table-column
          min-width="90"

          prop="handleUser"
          label="创建人"
          show-overflow-tooltip
        ></el-table-column> -->
        <el-table-column label="告警时间" min-width="130" prop="warnTime" show-overflow-tooltip></el-table-column>
        <!--        <el-table-column min-width="120" prop="warnType" label="告警类型" show-overflow-tooltip>-->
        <!--        </el-table-column>-->
        <el-table-column label="告警阈值" min-width="60" prop="warnThreshold" show-overflow-tooltip>
        </el-table-column>
        <el-table-column label="告警值" min-width="60" prop="warnData" show-overflow-tooltip>
        </el-table-column>
        <el-table-column label="告警缘由" min-width="100" prop="warnReason" show-overflow-tooltip>
        </el-table-column>
        <el-table-column label="处理状态" min-width="60" show-overflow-tooltip>
          <template slot-scope="scope">
            <div :style=" scope.row.handleStatus == '待处理'
                  ? { color: '#ff4949' }
                  : scope.row.handleStatus == '处理中'
                    ? { color: '#E6A23C' }
                    : scope.row.handleStatus == '已完结'
                      ? { color: '#13ce66' }
                      : scope.row.handleStatus == '已终止'
                        ? { color: '#409EFF' }
                        : { color: '#a9a9a9' }
              ">
              {{ scope.row.handleStatus }}
            </div>
          </template>
        </el-table-column>
        <el-table-column label="处理时间" min-width="130" prop="handleTime" show-overflow-tooltip>
        </el-table-column>
        <!--        <el-table-column min-width="120" prop="handleResult" label="处理结果" show-overflow-tooltip>-->
        <!--        </el-table-column>-->
        <!--        <el-table-column min-width="60" label="处理状态" show-overflow-tooltip>-->
        <!--          <template slot-scope="scope">-->
        <!--            <div :style="scope.row.handleStatus == '待调度'-->
        <!--              ? { color: '#E6A23C' }-->
        <!--              : scope.row.handleStatus == '处置完成'-->
        <!--                ? { color: '#13ce66' }-->
        <!--                : scope.row.handleStatus == '待处理'-->
        <!--                  ? { color: '#ff4949' }-->
        <!--                  : scope.row.handleStatus == '正在处置'-->
        <!--                    ? { color: '#409EFF' }-->
        <!--                    : scope.row.handleStatus == '已归档'-->
        <!--                      ? { color: '#191970' }-->
        <!--                      : scope.row.handleStatus == '已评估'-->
        <!--                        ? { color: '#8a2be2' }-->
        <!--                        : { color: '#a9a9a9' }-->
        <!--              ">-->
        <!--              {{ scope.row.handleStatus }}-->
        <!--            </div>-->
        <!--          </template>-->
        <!--        </el-table-column>-->
      </el-table>
      <el-pagination ref="paginationPanel" :current-page="queryParam.pageBean.page" :page-size="queryParam.pageBean.pageSize" :page-sizes="[20, 30, 40, 50]"
                     :total="total" align="right"
                     background
                     class="bbsl-pagination" layout="total, sizes, prev, pager, next, jumper"
                     @size-change="handleSizeChange" @current-change="handleCurrentChange"></el-pagination>
    </div>
    <RealTimeMonitorDialog ref="RealTimeMonitorDialog"></RealTimeMonitorDialog>
    <warning ref="warningForm"></warning>
  </div>
</template>

<script>
import warning from '@/components/warningDialog/warning.vue'
import {TableMixin} from '@/mixins/tableMixin'
import dangerousDevice from '@/api/device/dangerousDevice.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import RealTimeMonitorDialog from '@/components/detailsDialog/RealTimeMonitorDialog.vue'

export default {
  mixins: [TableMixin],
  components: {
    RealTimeMonitorDialog,
    warning
  },
  data() {
    return {
      querys: [
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 'warnTime',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'deviceName',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'handleStatus',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'warn.DEVICE_TYPE_',
          relation: 'AND',
          value: 4
        }
      ],
      deviceTypeList: [], //设备告警类型字典
      handleStatusList: [], //处理状态字典
      warnTypeList: [] //告警类型字典
    }
  },
  created() {
    if (this.$route.query.warnTime) {
      this.querys[0].value = [
        this.$route.query.warnTime,
        this.$route.query.warnTime
      ]
    }
    if (this.$route.query.deviceCode) {
      this.querys[1].value = this.$route.query.deviceCode
    }
    this.deviceTypeList = dictUtils.getDictItemsFromCache('gjsblx')
    this.handleStatusList = dictUtils.getDictItemsFromCache('clzt')
    this.warnTypeList = dictUtils.getDictItemsFromCache('gjlx')
  },
  methods: {
    handleUpdate(row) {
      console.log(row)
      this.$refs.warningForm.add(row)
    },
    toDialog(name) {
      this.$refs.RealTimeMonitorDialog.add(name)
    },
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
    },
    loadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.querys = []
      this.queryParam.sorter = [
        {
          direction: 'DESC',
          property: 'warnTime'
        }
      ]
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }

      dangerousDevice.loadInfo(this.queryParam, (res) => {
        // console.log(res, 'ppppppp')
        this.tableData = res.rows
        this.total = res.total
        this.$set(this.tableData)
        this.loading = false
        this.tableData.forEach((item) => {
          this.warnTypeList.forEach((val) => {
            if (item.warnType == val.value) {
              item['warnType'] = val.name
            }
          })
          this.handleStatusList.forEach((val) => {
            if (item.handleStatus == val.value) {
              item['handleStatus'] = val.name
            }
          })
        })
      })
    }
  }
}
</script>

<style lang="scss" scoped>
.active {
  color: #3399ff;
  cursor: pointer;
}
</style>
